import argparse
import sys
from .utils import *
from rich import *
from .beautifying import *
from .terminal import *
from .conversation import *

def main():
    try:
        parser = argparse.ArgumentParser(description="Check if a GitHub repository link is valid.", add_help=False)
        parser.add_argument("-h", "--help", action="store_true", help="Show this help message and exit")
        parser.add_argument("-u", "--url", help="The GitHub repository URL to check")
        parser.add_argument("-c", "--chat", action="store_true", help="Run a chat with the GitHub repository")
        parser.add_argument("-i", "--interactive", action="store_true", help="Run in interactive mode")
        parser.add_argument("-f", "--file", action="store_true", help="Run in interactive mode")
        args = parser.parse_args()
        
        clear_terminal()
        welcome_banner()

        if args.help:
            display_help_in_panel(parser)

        elif args.interactive:
            interactive_mode(parser)
        
        elif args.chat:
            #gemini_chat(parser)
            files = select_files_for_upload(temp_dir)
            gemini_upload_files(parser, files)

        elif args.url:
            try:
                if check_url(args.url):
                    analyze_repo(args.url)
                else:
                    rich_warning(f"The repository at {args.url} is not valid or does not exist.")
            except Exception as e:
                print(f"An error occurred: {e}", file=sys.stderr)
                clear_temp_dir("temp/")
                sys.exit(1)
        else:
            display_help_in_panel(parser)
            interactive_mode(parser)
    except KeyboardInterrupt:
        clear_temp_dir("temp/")
        rich_warning("Operation cancelled by user")
        sys.exit(0)

if __name__ == "__main__":
    main()